@@ -56,7 +56,7 @@ class SelectedMethodWgt(QtGui.QWidget):
                 self.resize(900,560)
             else:
                 self.resize(900, 726)
-        self.setMinimumHeight(300)
+        self.setMinimumHeight(100)
         self.setMinimumWidth(500)
         self.show()
 
@@ -192,13 +192,12 @@ def parse():
     import gettext
     try:
         set_lang = gettext.locale.getdefaultlocale()[0][:2]
-        lang = gettext.translation('console_gui', languages=[set_lang])
+        lang = gettext.translation('cl_consolegui3', languages=[set_lang],fallback=True)
+        try:
+            lang.install(unicode=True)
+        except UnboundLocalError:
+            pass
     except (IOError, TypeError):
-        lang = gettext.translation('console_gui', languages=['en'])
-
-    try:
-        lang.install(unicode=True)
-    except UnboundLocalError:
         pass
 
     import argparse
@@ -208,7 +207,7 @@ def parse():
         dest='help', help=_("show this help message and exit"))
     parser.add_argument( 
         '-l', '--lang', type=str, dest='lang',
-        help=_('language for translation'))
+        help=_("translation language"))
     parser.add_argument( 
         '--method', type=str, dest='method', 
         help=_('call method'))
@@ -300,7 +299,7 @@ class ToolTabWidget(QtGui.QTabWidget):
                 self.resize(900,560)
             else:
                 self.resize(900, 700)
-        self.setMinimumHeight(300)
+        self.setMinimumHeight(100)
         self.setMinimumWidth(500)
 
         self.setWindowTitle(self.Name)
