@@ -439,7 +439,9 @@ class MainFrameRes(QtGui.QWidget):
         """ get one message by its type """
         for case in switch(item.type):
             if case('normal'):
-
+                 self.show_normal(item)
+                 return 1
+            if case('plain'):
                  self.show_normal(item)
                  return 1
             if case('progress'):
@@ -518,8 +520,8 @@ class MainFrameRes(QtGui.QWidget):
             
     def get_Frame_cycle(self, current_frame, through_object):
         if type(current_frame) == Exception:
-            _print (_('Failed to get the frame from the server.'))
-            show_msg(_('Failed to get the frame from the server.') +'\n'+ \
+            _print (_("Failed to get a frame from the server."))
+            show_msg(_("Failed to get a frame from the server.") +'\n'+ \
                      _('Try resfeshing this page later.'),'get frame error')
             return 1
         sid, pid = through_object
@@ -594,7 +596,7 @@ class MainFrameRes(QtGui.QWidget):
     def get_entire_frame_after(self, current_frame, through_object):
         if type(current_frame) == Exception:
             _print (_('Failed to get the complete frame from the server.'))
-#            show_msg(_('Failed to get the frame from the server.') +'\n'+ \
+#            show_msg(_("Failed to get a frame from the server.") +'\n'+ \
 #                     _('Try resfeshing this page later.'),'get frame error')
             return 1
         sid, pid = through_object
@@ -782,14 +784,16 @@ class MessageDialog(QtGui.QWidget):
         if isPassword:
             self.pass_edit.setEchoMode(self.pass_edit.Password)
             if item.id == 2:        
-                self.pass_edit2 = QtGui.QLineEdit(self)
-                self.pass_edit2.setEchoMode(self.pass_edit2.Password)
+                if hasattr(self,'pass_edit2'):
+                    self.pass_edit2 = QtGui.QLineEdit(self)
+                    self.pass_edit2.setEchoMode(self.pass_edit2.Password)
                 
                 self.layout.addWidget(LabelWordWrap(_('Repeat'), self), x, 0)
                 self.layout.addWidget(self.pass_edit2, x, 1)
                 x += 1
                 self.pass_edit.textChanged.connect(self.check_passwd)
-                self.pass_edit2.textChanged.connect(self.check_passwd)
+                if hasattr(self,'pass_edit2'):
+                    self.pass_edit2.textChanged.connect(self.check_passwd)
 
         self.send_button = QtGui.QPushButton(_('Send'), self)
         self.send_button.setShortcut(QtGui.QKeySequence(QtCore.Qt.Key_Return))
@@ -808,7 +812,8 @@ class MessageDialog(QtGui.QWidget):
         
     def send_password(self):
         answer = self.pass_edit.text()
-        if answer == self.pass_edit2.text():
+        if not hasattr(self,"pass_edit2") or \
+            answer == self.pass_edit2.text():
             
             # Call server method
             if hasattr (self, 'send_password_thread'):
