@@ -202,10 +202,11 @@ class ShortFrameRes(QtGui.QWidget):
             if self.get_Progress_thread.isRunning():
                 self.get_Progress_thread.close()
                 self.get_Progress_thread.wait()
-        self.taskWidget.endCurrentTask()
-        
-        if item.message:
-            self.taskWidget.setText(item.message)
+        if hasattr(self,"taskWidget"):
+            self.taskWidget.endCurrentTask()
+            
+            if item.message:
+                self.taskWidget.setText(item.message)
         self.initUI()
 
     def beginFrame(self, item):
@@ -369,8 +370,8 @@ class ShortFrameRes(QtGui.QWidget):
 
     def get_Frame_cycle(self, current_frame, through_object):
         if type(current_frame) == Exception:
-            _print (_('Failed to get the frame from the server.'))
-            show_msg(_('Failed to get the frame from the server.') +'\n'+ \
+            _print (_("Failed to get a frame from the server."))
+            show_msg(_("Failed to get a frame from the server.") +'\n'+ \
                      _('Try resfeshing this page later.'),'get frame error')
             return 1
         sid, pid = through_object
@@ -444,7 +445,7 @@ class ShortFrameRes(QtGui.QWidget):
     def get_entire_frame_after(self, current_frame, through_object):
         if type(current_frame) == Exception:
             _print (_('Failed to get the complete frame from the server.'))
-            show_msg(_('Failed to get the frame from the server.') +'\n'+ \
+            show_msg(_("Failed to get a frame from the server.") +'\n'+ \
                      _('Try resfeshing this page later.'),'get frame error')
             return 1
         sid, pid = through_object
@@ -641,4 +642,4 @@ class MessageDialog(QtGui.QWidget):
         if self.pass_edit.text() != self.pass_edit2.text():
             self.send_button.setDisabled(True)
         else:
-            self.send_button.setEnabled(True)
\ No newline at end of file
+            self.send_button.setEnabled(True)
