@@ -14,21 +14,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from calculate.lib.datavars import ReadonlyVariable
-from calculate.consolegui.datavars import __version__,__app__
-
 import console
 
-section = "gui"
-
-class VariableClName(ReadonlyVariable):
-    """
-    Package name
-    """
-    value = __app__
-
-class VariableClVer(ReadonlyVariable):
-    """
-    Package version
-    """
-    value = __version__
+section = "consolegui"
